==> lqbox-1.1.0.tar.gz: lqbox-1.1.0/lqbox/open_elihu/__init__.py <==
# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2023/8/28 11:00:58
@Author  : zhchen
@Desc    : 
"""
import datetime
from typing import List

from base import BaseBox


class OpenElihuBox(BaseBox):
    base_url = "aHR0cHM6Ly9lbGlodS1taW5lci5sZXFlZS5jb20vb3BlbmFwaQ=="
    name1 = 'ZWxpaHUtb3Blbi1hcGktdHAtY29kZQ=='
    name2 = 'ZWxpaHUtb3Blbi1hcGktbm9pc2U='
    name3 = 'ZWxpaHUtb3Blbi1hcGktY2hlY2tzdW0='

    def __init__(self, tp_code, tp_secret):
        super().__init__(cookies={})
        self.tp_code = tp_code
        self.tp_secret = tp_secret

    def request_open_api(self, api_path, body):
        now = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')
        body[self.base64(self.name1)] = self.tp_code
        body[self.base64(self.name2)] = now
        body[self.base64(self.name3)] = self.md5(f'{self.tp_code}{now}{self.tp_secret}')
        r = self.request(method='POST', url=f'{self.base_url}/{api_path}', json=body)
        return r

    def call_check_task_detail(self, task_id: int) -> dict:
        """获取某个任务的状态"""
        return self.request_open_api(
            api_path="QueueOpenApiController/checkTaskDetail",
            body={"task_id": task_id}
        )

    def call_get_shovel_request_related_accounts(
            self,
            shovel_request_code: str,
            platform_code=None,
            shop_list=None,
            account_id=None
    ) -> List[dict]:
        """获取账号"""
        dictionary = {
            "shovel_request_code": shovel_request_code,
        }
        if platform_code is not None:
            dictionary['platform_code'] = platform_code
        if shop_list is not None:
            dictionary['shop_list'] = shop_list
        if account_id is not None:
            dictionary['account_id'] = account_id

        return self.request_open_api(
            "KaiwaOpenApiController/getShovelRequestRelatedAccounts",
            dictionary
        )

    def call_get_accounts_without_long_session(self, account_id_list: List[int], platform_code: str) -> List[int]:
        """筛选出没有可用的 LONG 类型的会话的 account_id"""
        return self.request_open_api(
            'KaiwaOpenApiController/getAccountsWithoutLongSession',
            {'account_id_list': account_id_list, 'platform_code': platform_code}
        )

==> lqbox-1.2.0.tar.gz: lqbox-1.2.0/lqbox/open_elihu/__init__.py <==
# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2023/8/28 11:00:58
@Author  : zhchen
@Desc    : 
"""
import datetime
from typing import List

from requests import Response

from lqbox.base import BaseBox


class OpenElihuBox(BaseBox):
    base_url = "aHR0cHM6Ly9lbGlodS1taW5lci5sZXFlZS5jb20vb3BlbmFwaQ=="
    name1 = 'ZWxpaHUtb3Blbi1hcGktdHAtY29kZQ=='
    name2 = 'ZWxpaHUtb3Blbi1hcGktbm9pc2U='
    name3 = 'ZWxpaHUtb3Blbi1hcGktY2hlY2tzdW0='

    def __init__(self, tp_code, tp_secret):
        super().__init__(cookies={})
        self.tp_code = tp_code
        self.tp_secret = tp_secret

    def request_open_api(self, api_path, body) -> Response:
        now = datetime.datetime.now().strftime('%Y%m%d%H%M%S%f')
        body[self.base64(self.name1)] = self.tp_code
        body[self.base64(self.name2)] = now
        body[self.base64(self.name3)] = self.md5(f'{self.tp_code}{now}{self.tp_secret}')
        r = self.request(method='POST', url=f'{self.base_url}/{api_path}', json=body)
        return r

    def call_check_task_detail(self, task_id: int) -> Response:
        """获取某个任务的状态"""
        return self.request_open_api(
            api_path="QueueOpenApiController/checkTaskDetail",
            body={"task_id": task_id}
        )

    def call_get_shovel_request_related_accounts(
            self,
            shovel_request_code: str,
            platform_code=None,
            shop_list=None,
            account_id=None
    ) -> Response:
        """获取账号"""
        dictionary = {
            "shovel_request_code": shovel_request_code,
        }
        if platform_code is not None:
            dictionary['platform_code'] = platform_code
        if shop_list is not None:
            dictionary['shop_list'] = shop_list
        if account_id is not None:
            dictionary['account_id'] = account_id

        return self.request_open_api(
            "KaiwaOpenApiController/getShovelRequestRelatedAccounts",
            dictionary
        )

    def call_get_accounts_without_long_session(self, account_id_list: List[int], platform_code: str) -> Response:
        """筛选出没有可用的 LONG 类型的会话的 account_id"""
        return self.request_open_api(
            'KaiwaOpenApiController/getAccountsWithoutLongSession',
            {'account_id_list': account_id_list, 'platform_code': platform_code}
        )
